Package: qvirus
Title: Quantum Computing for Analyzing CD4 Lymphocytes and
        Antiretroviral Therapy
Version: 0.0.6
Authors@R: 
    person("Juan Pablo", "Acuña González", , "22253567@uagro.mx", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0009-0003-6029-6560"))
Description: Resources, tutorials, and code snippets dedicated to exploring the intersection of quantum computing and artificial intelligence (AI) in the context of analyzing Cluster of Differentiation 4 (CD4) lymphocytes and optimizing antiretroviral therapy (ART) for human immunodeficiency virus (HIV). With the emergence of quantum artificial intelligence and the development of small-scale quantum computers, there's an unprecedented opportunity to revolutionize the understanding of HIV dynamics and treatment strategies. This project leverages a quantum computer simulator, to explore these applications in quantum computing techniques, addressing the challenges in studying CD4 lymphocytes and enhancing ART efficacy.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 3.5)
LazyData: true
Suggests: rmarkdown, testthat (>= 3.0.0)
Config/testthat/edition: 3
Imports: dplyr, magrittr, stats
NeedsCompilation: no
Packaged: 2026-04-15 18:44:39 UTC; jp
Author: Juan Pablo Acuña González [aut, cre, cph] (ORCID:
    <https://orcid.org/0009-0003-6029-6560>)
Maintainer: Juan Pablo Acuña González <22253567@uagro.mx>
Repository: CRAN
Date/Publication: 2026-04-15 19:10:02 UTC
Built: R 4.5.2; ; 2026-04-20 23:33:16 UTC; unix
