# Generated by roxygen2: do not edit by hand

S3method(mse,InteractionClassification)
S3method(mse,payoffs)
S3method(summary,InteractionClassification)
S3method(summary,payoffs)
export(InteractionClassification)
export(cd_diff)
export(cds_diff)
export(estimate_payoffs)
export(mse)
export(nearest_payoff)
export(payoffs_list)
export(phen_hiv)
export(run_bb84_simulation)
export(run_e91_simulation)
export(summary)
export(vl_diff)
export(vlog_diff)
export(vlogs_diff)
