# `nearest_payoff()` works as expected

    Code
      nearest_payoff(-0.2, pays)
    Output
      $value
      v_I_H 
       0.15 
      
      $name
      [1] "v_I_H"
      
      attr(,"class")
      [1] "NearestPayoff" "list"         

