# phen_hiv() works as expected

    Code
      phen_hiv(strategy1, strategy2, alpha, beta, gamma, theta)
    Output
        prob_00 prob_01 prob_10 prob_11 pi_v pi_V
      1       1       0       0       0    1    1

