% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mse.InteractionClassification.R
\name{mse.InteractionClassification}
\alias{mse.InteractionClassification}
\title{Mean Squared Errors for Interaction Classification}
\usage{
\method{mse}{InteractionClassification}(object, ...)
}
\arguments{
\item{object}{An object of class \code{InteractionClassification} containing
the classified data and clustering results.}

\item{...}{Additional arguments passed to other methods (currently not used).}
}
\description{
Mean squared errors (MSE) for viral load differences
and CD4 count differences by comparing the actual values with the group means
from the classification.
}
